#include <math.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>

const long MAX_DIGITS = 3000; //2002
const long DIGITS_CENTER = MAX_DIGITS / 2;

class CNumber
{
	int mPositive;
	long mDigits[MAX_DIGITS];

	void Normalize(void)
	{
		long iDigit;
		for(iDigit = 0; iDigit < MAX_DIGITS - 1; ++iDigit)
			if(mDigits[iDigit] > 9)
			{
				++mDigits[iDigit + 1];
				mDigits[iDigit] -= 10;
			}
			else if(mDigits[iDigit] < 0)
			{
				--mDigits[iDigit + 1];
				mDigits[iDigit] += 10;
			}
	}
public:
	CNumber(void)
	{
		mPositive = 1;
		memset(mDigits, 0, sizeof(mDigits));
	}

	CNumber(const CNumber &number)
	{
		mPositive = number.mPositive;
		memcpy(mDigits, number.mDigits, sizeof(mDigits));
	}

	const CNumber& operator = (const CNumber &number)
	{
		mPositive = number.mPositive;
		memcpy(mDigits, number.mDigits, sizeof(mDigits));
		return *this;
	}

	void Read(void)
	{
		char part1[MAX_DIGITS], part2[MAX_DIGITS], sign[MAX_DIGITS];
		*sign = 0;
		*part1 = 0;
		*part2 = 0;
		scanf(" ");
		scanf("%[+-]", sign);
		scanf("%[^. \n\t]", part1);
		scanf("%*[.]");
		scanf("%[^ \n\t]", part2);
		scanf(" ");
		long iDigit;
		if(sign[0] == '-')mPositive = 0;
		else mPositive = 1;
		long length1 = strlen(part1);
		long length2 = strlen(part2);
		for(iDigit = 0; iDigit < length1; ++iDigit)
			mDigits[DIGITS_CENTER + length1 - iDigit - 1] = part1[iDigit] - '0';
		for(iDigit = 0; iDigit < length2; ++iDigit)
			mDigits[DIGITS_CENTER - iDigit - 1] = part2[iDigit] - '0';
	}

	void ModAdd(const CNumber &number)
	{
		long iDigit;
		for(iDigit = 0; iDigit < MAX_DIGITS; ++iDigit)
			mDigits[iDigit] += number.mDigits[iDigit];
		Normalize();
	}

	void ModSub (const CNumber &number)
	{
		long iDigit;
		for(iDigit = 0; iDigit < MAX_DIGITS; ++iDigit)
			mDigits[iDigit] -= number.mDigits[iDigit];
		Normalize();
	}

	int ModLt (const CNumber &number) const
	{
		long iDigit;
		for(iDigit = MAX_DIGITS - 1; iDigit >= 0; --iDigit)
			if(mDigits[iDigit] < number.mDigits[iDigit])return 1;
			else if(mDigits[iDigit] > number.mDigits[iDigit])return 0;
		return 0;
	}

	CNumber operator + (const CNumber &number)
	{
		CNumber result;
		if(mPositive && number.mPositive)
		{
			result = *this;
			result.ModAdd(number);
			result.mPositive = 1;
		}
		else if(mPositive && ! number.mPositive)
		{
			if(number.ModLt(*this) )
			{
				result = *this;
				result.ModSub(number);
				result.mPositive = 1;
			}
			else
			{
				result = number;
				result.ModSub(*this);
				result.mPositive = 0;
			}
		}
		else if(! mPositive && number.mPositive)
		{
			if(number.ModLt(*this))
			{
				result = *this;
				result.ModSub(number);
				result.mPositive = 0;
			}
			else
			{
				result = number;
				result.ModSub(*this);
				result.mPositive = 1;
			}
		}
		else
		{
				result = *this;
				result.ModAdd(number);
				result.mPositive = 0;
		}

		return result;
	}

	void Print(void)
	{
		long iDigit;
		int zero = 1;
		for(iDigit = 0; iDigit < MAX_DIGITS; ++iDigit)
			if(mDigits[iDigit])break;
		zero = (iDigit == MAX_DIGITS);
		if(! mPositive && ! zero)putchar('-');
		for(iDigit = MAX_DIGITS - 1; iDigit >= DIGITS_CENTER; --iDigit)
			if(mDigits[iDigit])break;
		if(iDigit == DIGITS_CENTER - 1)putchar('0');
		for(; iDigit >= DIGITS_CENTER; --iDigit)
			putchar(mDigits[iDigit] + '0');
		putchar('.');
		for(iDigit = 0; iDigit < DIGITS_CENTER; ++iDigit)
			if(mDigits[iDigit])break;
		if(iDigit == DIGITS_CENTER)putchar('0');
		else
		{
			long end = iDigit;
			for(iDigit = DIGITS_CENTER - 1; iDigit >= end; --iDigit)
				putchar(mDigits[iDigit] + '0');
		}
	}
};

int main(void)
{
#ifndef ONLINE_JUDGE
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);
#endif

	long cNumbers, iNumber;
	scanf("%ld", &cNumbers);
	for(iNumber = 0; iNumber < cNumbers; ++iNumber)
	{
		CNumber a, b, c;
		a.Read();
		b.Read();
		c = a + b;
		c.Print();
		putchar('\n');
	}

#ifndef ONLINE_JUDGE
	fclose(stdout);
	fclose(stdin);
#endif

	return 0;
}